Configuration
=============

Configuration classes for RKNN model export and runtime.

RKNN Configuration
------------------

.. autoclass:: rktransformers.configuration.RKNNConfig
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__

Quantization Configuration
--------------------------

.. autoclass:: rktransformers.configuration.QuantizationConfig
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__

Optimization Configuration
--------------------------

.. autoclass:: rktransformers.configuration.OptimizationConfig
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__
